==> hlw-core-0.0.2-20251017.082150-153-sources.jar: cn/gtmap/hlw/core/model/GxYyDjdc.java <==
package cn.gtmap.hlw.core.model;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.util.List;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2025/6/17
 * @description 地籍调查表申请表
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class GxYyDjdc implements Serializable {
    private static final long serialVersionUID = 1446890073489787592L;
    /**
     * 主键
     */
    private String id;
    /**
     * 申请id
     */
    private String sqid;
    /**
     * 成果类型（字典表gx_yy_zd_type key：cgdc）
     */
    private String cglx;
    /**
     * 测绘类型类型（字典表gx_yy_zd_type key：chlx，支持逗号拼接）
     */
    private String chlx;
    /**
     * 项目名称
     */
    private String xmmc;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 土地用途（字典表gx_yy_zd_tdyt，支持逗号拼接）
     */
    private String tdyt;
    /**
     * 面积（单位：平方米）
     */
    private Double mj;
    /**
     * 单体规划功能
     */
    private String dtghgn;
    /**
     * 土地权属来源证明材料
     */
    private String tdqslyzmcl;
    /**
     * 备注
     */
    private String bz;
    /**
     * 单位名称
     */
    private String dwmc;
    /**
     * 地块名称
     */
    private String dkmc;
    /**
     * 服务类别代码
     */
    private String fwlbdm;
    /**
     * 街道（乡镇）
     */
    private String jdxz;
    /**
     * 委托人
     */
    private String wtr;
    /**
     * 委托人证件号
     */
    private String wtrzjh;
    /**
     * 委托人联系电话
     */
    private String wtrlxdh;
    /**
     * 委托代理人
     */
    private String wtdlr;
    /**
     * 委托代理人证件号
     */
    private String wtdlrzjh;
    /**
     * 委托代理人联系电话
     */
    private String wtdlrlxdh;
    /**
     * 服务类别代码集合
     */
    private List<String> fwlbdmList;
}

==> hlw-core-0.0.2-20251119.064409-171-sources.jar: cn/gtmap/hlw/core/model/GxYyDjdc.java <==
package cn.gtmap.hlw.core.model;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.util.List;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2025/6/17
 * @description 地籍调查表申请表
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class GxYyDjdc implements Serializable {
    private static final long serialVersionUID = 1446890073489787592L;
    /**
     * 主键
     */
    private String id;
    /**
     * 申请id
     */
    private String sqid;
    /**
     * 成果类型（字典表gx_yy_zd_type key：cgdc）
     */
    private String cglx;
    /**
     * 测绘类型类型（字典表gx_yy_zd_type key：chlx，支持逗号拼接）
     */
    private String chlx;
    /**
     * 项目名称
     */
    private String xmmc;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 土地用途（字典表gx_yy_zd_tdyt，支持逗号拼接）
     */
    private String tdyt;
    /**
     * 面积（单位：平方米）
     */
    private Double mj;
    /**
     * 单体规划功能
     */
    private String dtghgn;
    /**
     * 土地权属来源证明材料
     */
    private String tdqslyzmcl;
    /**
     * 备注
     */
    private String bz;
    /**
     * 单位名称
     */
    private String dwmc;
    /**
     * 单位证件种类
     */
    private String dwzjlx;
    /**
     * 单位证件号
     */
    private String dwzjh;
    /**
     * 地块名称
     */
    private String dkmc;
    /**
     * 服务类别代码
     */
    private String fwlbdm;
    /**
     * 街道（乡镇）
     */
    private String jdxz;
    /**
     * 委托人
     */
    private String wtr;
    /**
     * 委托人证件号
     */
    private String wtrzjh;
    /**
     * 委托人联系电话
     */
    private String wtrlxdh;
    /**
     * 委托代理人
     */
    private String wtdlr;
    /**
     * 委托代理人证件号
     */
    private String wtdlrzjh;
    /**
     * 委托代理人联系电话
     */
    private String wtdlrlxdh;
    /**
     * 委托代理人证件类型
     */
    private String wtdlrzjlx;
    /**
     * 服务类别代码集合
     */
    private List<String> fwlbdmList;
    /**
     * 调查类型
     */
    private String dclxdm;
    /**
     * 土地所有权性质
     */
    private String tdsyqxzdm;
    /**
     * 宗地宗海特征
     */
    private String zdzhtzdm;
    /**
     * 特殊地籍子区编码
     */
    private String tsdjzqbm;
    /**
     * 调查机构
     */
    private String dcjg;
    /**
     * 任务名称
     */
    private String rwmc;
}
